@@ -6,19 +6,19 @@ from math import floor, ceil
 import asyncio
 
 from PIL.Image import Image
-from typing import Coroutine
+from typing import Coroutine, Sequence
 from types import MappingProxyType
 
 from ..pssm_types import PSSMlayout
 from ..exceptions import *
 from . import baseelements as base
 from . import compoundelements as comps     ##May need restructuring here if I want to use compounds with grid elements -> Nope probably? Since that would kinda take away some configuration
-from . baseelements import Element
+from .baseelements import Element, elementactionwrapper, elementaction, colorproperty
 from .constants import DEFAULT_ACCENT_COLOR, DEFAULT_BACKGROUND_COLOR, DEFAULT_FOREGROUND_COLOR
 from ..pssm_types import *
 from .. import tools
 
-logger = base.logger
+_LOGGER = base._LOGGER
 
 class _GridElement(base.Element):
     """
@@ -33,13 +33,13 @@ class _GridElement(base.Element):
     @grid_row.setter
     def grid_row(self, value):
         if value != None and not isinstance(value, int):
-            logger.warning(f"{self}: grid_row must be None or a positive integer")
+            _LOGGER.warning(f"{self}: grid_row must be None or a positive integer")
             return
         
         if value == None:
             pass
         elif value < 1:
-            logger.warning(f"{self}: grid_row must be at least 1")
+            _LOGGER.warning(f"{self}: grid_row must be at least 1")
             return
         
         self._grid_row = value
@@ -56,13 +56,13 @@ class _GridElement(base.Element):
     @grid_column.setter
     def grid_column(self, value):
         if value != None and not isinstance(value, int):
-            logger.warning(f"{self}: grid_column must be None or a positive integer")
+            _LOGGER.warning(f"{self}: grid_column must be None or a positive integer")
             return
         
         if value == None:
             pass
         elif value < 1:
-            logger.warning(f"{self}: grid_column must be at least 1")
+            _LOGGER.warning(f"{self}: grid_column must be at least 1")
             return
         
         self._grid_column = value
@@ -87,7 +87,8 @@ class GridLayout(base.Layout):
     Elements that are added to it (either at initialisation or via `GridLayout.add_elements`) will be given a `grid_row` and `grid_column` attribute with functionality to notify the GridLayout that their position changed.
     Elements do not need a value for `grid_row` and `grid_column`, in which case the GridLayout will attempt to place them later on in the leftover empty cells.
     Any elements that overflow the available number of grid cells, or have their `grid_row` and `grid_column` overlap with that of another Element will not be put in the Layout, but will be saved for new iterations of the GridLayout in case space becomes available.
-    
+    `rows` or `columns` can be set to `None`, in which case they will be set as needed by the number of elements. However, it is not allowed to set both to `None`.
+
     Parameters
     ----------
     elements : list[base.Element]
@@ -95,8 +96,10 @@ class GridLayout(base.Layout):
         Can be assigned a location by setting `grid_row` and `grid_column` (Keep in mind indices start at 0)
     rows : int, optional
         The number of rows, by default 4
+        If None, the rows will be set depending on the number of elements
     columns : int, optional
         The number of columns, by default 4
+        If None, the columns will be set depending on the number of elements
     row_sizes : list[PSSMdimension], optional
         The sizes (heights) of the rows, by default "?"
         If a single value, all rows will be assigned that size. 
@@ -115,7 +118,7 @@ class GridLayout(base.Layout):
     @property
     def _emulator_icon(cls): return "mdi:dots-grid"
     
-    def __init__(self, elements : list[base.Element], rows : int = 4, columns : int = 4,
+    def __init__(self, elements : Sequence[base.Element], rows : int = 4, columns : int = 4,
                 row_sizes : list[PSSMdimension] = "?", column_sizes : list[PSSMdimension] = "?",
                 outer_margins : list[PSSMdimension] = 0, inner_margins : list[PSSMdimension] = 0, **kwargs):
 
@@ -161,12 +164,12 @@ class GridLayout(base.Layout):
         l = len(value)
         if not 1 <= l <= 4:
             msg = f"{self}: margins cannot be set to {value}, value must be a single dimension, or a list of 1 to 4 dimensions"
-            logger.exception(msg)
+            _LOGGER.exception(msg)
 
         for m in value.copy():
             res = tools.is_valid_dimension(m)
             if isinstance(res, Exception):
-                logger.exception(res)
+                _LOGGER.exception(res)
                 return
 
         l = len(value)
@@ -198,12 +201,12 @@ class GridLayout(base.Layout):
         l = len(value)
         if not 1 <= l <= 4:
             msg = f"{self}: margins cannot be set to {value}, value must be a single dimension, or a list of 1 to 4 dimensions"
-            logger.exception(msg)
+            _LOGGER.exception(msg)
 
         for m in value.copy():
             res = tools.is_valid_dimension(m)
             if isinstance(res, Exception):
-                logger.exception(res)
+                _LOGGER.exception(res)
                 return
 
         l = len(value)
@@ -228,7 +231,7 @@ class GridLayout(base.Layout):
     def rows(self, value):
         if value != None and not isinstance(value,int):
             msg = f"{self}: rows must be either None or an integer. Value {value} with type {type(value)} is not valid"
-            logger.exception(TypeError(msg))
+            _LOGGER.exception(TypeError(msg))
             return
         self._rows = value
 
@@ -253,7 +256,7 @@ class GridLayout(base.Layout):
     def columns(self, value):
         if value != None and not isinstance(value,int):
             msg = f"{self}: columns must be either None or an integer. Value {value} with type {type(value)} is not valid"
-            logger.exception(TypeError(msg))
+            _LOGGER.exception(TypeError(msg))
             return
         self._columns = value
 
@@ -284,7 +287,7 @@ class GridLayout(base.Layout):
             if isinstance(elt,(str,dict,MappingProxyType)):
                 if isinstance(elt,(dict,MappingProxyType)):
                     if "element_id" not in elt:
-                        logger.exception(f"{self}: Passing an element as a dict to a GridLayout requires the 'element_id' key")
+                        _LOGGER.exception(f"{self}: Passing an element as a dict to a GridLayout requires the 'element_id' key")
                         continue
                     elt = elt["element_id"]
 
@@ -295,11 +298,11 @@ class GridLayout(base.Layout):
                     continue
                 else:
                     msg = f"No element with element id {elt} is registered."
-                    logger.exception(msg)
+                    _LOGGER.exception(msg)
                     continue
 
             if elt in self.__elements:
-                logger.warning(f"Element {elt} is already in grid {self}")
+                _LOGGER.warning(f"Element {elt} is already in grid {self}")
                 continue
 
             if not isinstance(elt, _GridElement) and isinstance(elt, Element):
@@ -322,7 +325,7 @@ class GridLayout(base.Layout):
         for elt_str in self.__element_strings:
             if elt_str not in self.screen.elementRegister:
                 msg = f"No element with element id {elt_str} is registered."
-                logger.exception(msg)
+                _LOGGER.exception(msg)
                 continue
             else:
                 elt = self.screen.elementRegister[elt_str]
@@ -341,7 +344,7 @@ class GridLayout(base.Layout):
         
         if num_columns == num_rows == None:
             msg = f"{self}: number of rows and number of columns cannot both be 0!"
-            logger.exception(ValueError(msg))
+            _LOGGER.exception(ValueError(msg))
             return
         
         if num_columns == None or num_rows == None:
@@ -365,13 +368,13 @@ class GridLayout(base.Layout):
                 continue
 
             if elt.grid_row >= num_rows or elt.grid_column >= num_columns:
-                logger.warning(f"{self}: {elt} has grid position ({elt.grid_column+1},{elt.grid_row+1}) (grid_column {elt.grid_column}, grid_row {elt.grid_row}), but exeeds grid size of ({num_columns},{num_rows})")    
+                _LOGGER.warning(f"{self}: {elt} has grid position ({elt.grid_column+1},{elt.grid_row+1}) (grid_column {elt.grid_column}, grid_row {elt.grid_row}), but exeeds grid size of ({num_columns},{num_rows})")    
                 assign_later.append(elt)
                 continue
             
             grid_fill = grid[elt.grid_row][elt.grid_column]
             if grid_fill != None:
-                logger.warning(f"{self}: {elt} has grid position ({elt.grid_column},{elt.grid_row}), but it is already assigned to element {grid_fill}")    
+                _LOGGER.warning(f"{self}: {elt} has grid position ({elt.grid_column},{elt.grid_row}), but it is already assigned to element {grid_fill}")    
                 assign_later.append(elt)
                 continue
 
@@ -395,7 +398,7 @@ class GridLayout(base.Layout):
                 
         if assign_later:
             msg = f"{self}: made a grid, but not all elements fitted. {assign_later} are omitted."
-            logger.warning(msg)
+            _LOGGER.warning(msg)
 
         return grid
 
@@ -499,9 +502,11 @@ class NavigationTile(base._TileBase):
     def _emulator_icon(cls): return "mdi:navigation-variant"
 
     def __init__(self, tile_layout : str, icon : mdiType, name : str, **kwargs): 
-        NavIcon = base.Icon(icon, background_shape="circle")
-        NavText = base.Button(name, text_x_position="left")
-        NavLine = base.Line(line_color=None, width=4, alignment="top")
+        NavIcon = base.Icon(icon, background_shape="circle", _isNavElt=True, NavTile = self)
+        if icon == None:
+            NavIcon._icon = None
+        NavText = base.Button(name, text_x_position="left", fit_text=True, _isNavElt=True, NavTile = self)
+        NavLine = base.Line(line_color=None, width=4, alignment="top", _isNavElt=True, NavTile = self)
 
         self.__elements = {"icon": NavIcon, "name": NavText, "line": NavLine}
         super().__init__(tile_layout,**kwargs)
@@ -538,6 +543,16 @@ class NavigationTile(base._TileBase):
 
     def update(self, updateAttributes={}, skipGen=False, forceGen: bool = False, skipPrint=False, reprintOnTop=False, updated: bool = False):
         return super().update(updateAttributes, skipGen, forceGen, skipPrint, reprintOnTop, updated)
+    
+    async def async_update(self, updateAttributes=..., skipGen=False, forceGen = False, skipPrint=False, reprintOnTop=False, updated = False):
+        upd = await super().async_update(updateAttributes, skipGen=True)
+        await asyncio.sleep(0)
+        await super().async_update({}, skipGen, forceGen, skipPrint, reprintOnTop, updated=updated or upd)
+        return upd
+
+    async def async_generate(self, area=None, skipNonLayoutGen=False):
+        await asyncio.sleep(0)
+        return await super().async_generate(area, skipNonLayoutGen)
 
     def generator(self, area=None, skipNonLayoutGen=False):
         img = super().generator(area, skipNonLayoutGen)
@@ -616,7 +631,7 @@ class TabPages(base._TileBase):
     def __init__(self, tabs : list[tabDict], tile_layout : Union[Literal["top","bottom","left","right"], PSSMLayoutString] = "bottom",
                 apply_default_sizes : bool = True, navigation_tile_size : Union[float,PSSMdimension] = 0.2,
                 hide_navigation_bar : bool = False, hide_page_handles : bool = True, cycle : bool = True,
-                element_properties : dict = {},
+                element_properties : dict = {}, horizontal_sizes: dict[str,PSSMdimension] = {}, vertical_sizes: dict[str,PSSMdimension] = {},
                 **kwargs) -> None:
 
         BackHandle = base.Icon("mdi:menu-left", icon_color='foreground', tap_action = self.previous_page)
@@ -654,8 +669,8 @@ class TabPages(base._TileBase):
         self.cycle = cycle
         self.navigation_tile_size = navigation_tile_size
 
-        vertical_sizes = {}
-        horizontal_sizes = {}
+        vertical_sizes = vertical_sizes
+        horizontal_sizes = horizontal_sizes
 
         super().__init__(tile_layout, vertical_sizes=vertical_sizes, horizontal_sizes=horizontal_sizes, element_properties=element_properties, **kwargs)
 
@@ -773,7 +788,7 @@ class TabPages(base._TileBase):
             return
         r = tools.is_valid_dimension(value)
         if isinstance(r,Exception):
-            logger.exception(r)
+            _LOGGER.exception(r)
             return
         self._navigation_tile_size = value
 
@@ -810,7 +825,7 @@ class TabPages(base._TileBase):
         """        
         
         if name in self.__tabNames:
-            logger.warning(f"{self}: A tab with name {name} already exists in this element. Not adding it.")
+            _LOGGER.warning(f"{self}: A tab with name {name} already exists in this element. Not adding it.")
             return
         
         if isinstance(element,str):
@@ -826,6 +841,9 @@ class TabPages(base._TileBase):
 
         issub = True
         NavElement = NavigationTile("auto", icon, name, _isSubLayout=issub)
+        # for prop, val in NavElement._color_shorthands.items():
+        #     setattr(NavElement,val,prop)
+
 
         self.__NavBar.add_elements(NavElement)
         self.__NavBar.add_option(name, NavElement)
@@ -855,6 +873,7 @@ class TabPages(base._TileBase):
             self.__tabs[tab_name] = tabConf
             return
 
+
     async def async_show_page(self, index : int):
         """
         Shows the tab at page index index
@@ -871,7 +890,7 @@ class TabPages(base._TileBase):
             index = index + len(self.__tabElements)
 
         if index >= len(self.__tabElements):
-            logger.warning(f"{self}: Has {len(self.__tabElements)} tabs, and index {index} is out of range (Keep in mind you can use indices start at 0 and go up to (number_of_tabs -1))")
+            _LOGGER.warning(f"{self}: Has {len(self.__tabElements)} tabs, and index {index} is out of range (Keep in mind you can use indices start at 0 and go up to (number_of_tabs -1))")
             return
         
         self._currentIdx = index
@@ -910,7 +929,7 @@ class TabPages(base._TileBase):
 
         if name not in self.__tabNames:
             msg = f"{self}: {name} is not the name of a registered tab."
-            logger.warning(msg)
+            _LOGGER.warning(msg)
             return 
 
         tab_idx = self.__tabNames.index(name)
@@ -930,29 +949,32 @@ class TabPages(base._TileBase):
 
         if option not in self.__tabNames:
             msg = f"{self}: {option} is not the name of a registered tab."
-            logger.warning(msg)
+            _LOGGER.warning(msg)
             return 
 
         tab_idx = self.__tabNames.index(option)
         await self.async_show_page(tab_idx)
         
-    async def show_tab_shorthand(self, *args, name : str):
+    @elementactionwrapper.method
+    async def show_tab_shorthand(self, name : str):
         """
         Helper function that can be used as an element's tap_action to navigate to tab with the provided name, or other shorthands.
         Can be used by setting it as an element's tap_action, via `{'action' : 'show-tab', 'data': {'name': 'my-tab'}}`
         """        
         if name not in self.__tabNames:
             msg = f"{self}: {name} is not the name of a registered tab."
-            logger.warning(msg)
+            _LOGGER.warning(msg)
             return 
 
         tab_idx = self.__tabNames.index(name)
         await self.async_show_page(tab_idx)
     
-    async def show_page_shorthand(self, *args, index : int):
+    @elementactionwrapper.method
+    async def show_page_shorthand(self, index : int):
         "Function that can be used as a tap_action i.e. to show a page with a certain number"
         await self.async_show_page(index)
 
+    @elementactionwrapper.method
     def next_page(self, *args):
         """
         Shows the next tab in the list of tabs. If cycle is not `True` and the last page is currently being shown, will do nothing.
@@ -966,6 +988,7 @@ class TabPages(base._TileBase):
 
         self.show_page(new_idx)
 
+    @elementactionwrapper.method
     def previous_page(self, *args):
         """
         Shows the previous tab in the list of tabs. If cycle is not `True` and the first page is currently being shown, will do nothing.
