@@ -82,10 +82,10 @@ class PSSMScreen:
 
     def __new__(cls, *args, **kwargs):
         if not hasattr(PSSMScreen,"_instance"):
-            PSSMScreen._instance = object.__new__(cls)
-            return PSSMScreen._instance
+            cls._instance = object.__new__(cls)
+            return cls._instance
         else:
-            screen = PSSMScreen._instance
+            screen = cls._instance
             return screen
     
     @staticmethod
@@ -544,7 +544,7 @@ class PSSMScreen:
                 raise DuplicateElementError(msg)
         else:
             self.__elementRegister[id] = element
-            if element.isPopup: self._register_popup(element)
+            if element.isPopup and element.popupID: self._register_popup(element)
 
             for func in self.__elementRegisterCallbacks:
                 func(element)
@@ -688,7 +688,7 @@ class PSSMScreen:
                 except ElementNotRegistered as e:
                     checks_passed = False
                     _LOGGER.error(f"Attribute {attr} check for element {elt} failed: {e}")
-        
+
         delattr(self,"_element_checks")
         return checks_passed
 
@@ -740,7 +740,6 @@ class PSSMScreen:
             if self.mainLoop.is_running():
                 if not self._printGather.done(): 
                     self._printGather.cancel("Quit was requested")
-                # self._eStop.set_exception(ReloadWarning)
                 self._eStop.set_exception(exce)
         except Exception as e:
             _LOGGER.error(f"Something went wrong quitting inkBoard: {e}")
@@ -781,11 +780,11 @@ class PSSMScreen:
             [(x, y), (w, h)] = self.area
 
         if pil_image == None:
-            _LOGGER.error("Something went wrong printing the Stack?")
+            _LOGGER.error("Something went wrong printing the Stack")
             raise ValueError("pil_image for stack print cannot be None")
         
         await asyncio.to_thread(self.device.print_pil, pil_image, x,y, isInverted=self.isInverted)
-        _LOGGER.trace("Printed stack")
+        _LOGGER.verbose("Printed stack")
 
     async def generate_stack(self,area=None, forceLayoutGen=False) -> Image.Image:
         """
@@ -859,7 +858,7 @@ class PSSMScreen:
         else:
             return img
 
-    def simple_print_element(self, element : "Element", skipGen=False, apply_background : bool = False, safe_print : bool = True):
+    def simple_print_element(self, element : "Element", skipGen=False, area: PSSMarea = None, apply_background : bool = False, safe_print : bool = True):
         """
         Prints the Element without adding it to the stack, if not in it.
         Does not honor isBatch (you can simplePrint even during batch mode)
@@ -888,7 +887,10 @@ class PSSMScreen:
             _LOGGER.warning(f"Cannot print element {element.id} before it has  an area set.")
             return
         
-        [(x, y), (w, h)] = element.area
+        if area:
+            [(x, y), (w, h)] = area
+        else:
+            [(x, y), (w, h)] = element.area
 
         if not self.printing:
             _LOGGER.warning("Cannot print to screen when not printing")
@@ -916,7 +918,15 @@ class PSSMScreen:
                 img = new_img
             else:
                 bg = Style.get_color(element.parentBackground, self.imgMode)
-                new_img = Image.new(self.imgMode,img.size, bg)
+                new_img = Image.new(self.imgMode, img.size, bg)
+                
+                if "A" in self.imgMode and bg[-1] != 255:
+                    crop_box = [x,y,x+w,y+h]
+                    bg_img = self.backgroundImage.crop(crop_box)
+                    bg_img.paste(new_img, mask=new_img)
+                    # bg_img.paste(new_img)
+                    new_img = bg_img
+                
                 new_img.paste(img, mask=img)
                 img = new_img
 
@@ -1148,8 +1158,9 @@ class PSSMScreen:
             _LOGGER.warning('Cannot remove element, no element given')
             return
         
-        if callable(f := getattr(element,"on_remove",None)):
-            ##Maybe these should be regular functions, like on_add
+        if isinstance(element, elements.Layout):
+            await asyncio.to_thread(element.remove_element)
+        elif callable(f := getattr(element,"on_remove",None)):
             a = tools.wrap_to_coroutine(f)
             asyncio.create_task(a)
 
@@ -1195,7 +1206,8 @@ class PSSMScreen:
             Save only or save + print? (Only used if inverDuration <= 0), by default False
         """   
 
-        _LOGGER.trace("Inverting an element")
+        _LOGGER.verbose(f"Inverting element {element}")
+        ##This calls screen refresh etc, so this will have to be handled.
         if element is None:
             _LOGGER.warning("Cannot invert Element, No element given")
             return False
@@ -1349,9 +1361,10 @@ class PSSMScreen:
     def _register_popup(self, popup: "elements.Popup"):
         "Adds this popup to the popup register"
         id = popup.popupID
-        if not id in self.__popupRegister:
+        
+        if id and id not in self.__popupRegister:
             self.__popupRegister[id] = popup
-        else:
+        elif id:
             msg = f"A popup with id {id} is already registered."
             _LOGGER.error(ValueError(msg))
             if const.RAISE: raise ValueError(msg)
@@ -1541,7 +1554,7 @@ class PSSMScreen:
         res
             _description_
         """
-        _LOGGER.trace("Handling a click")
+        _LOGGER.verbose("Handling a click")
         n = len(self.stack)
         coro_list = []
         self._lastCoords = (x,y)
@@ -1555,7 +1568,7 @@ class PSSMScreen:
                     coro_list.append(self.on_interact(**self.on_interact_data, screen = self, coords = InteractEvent(x,y, action)))
                 else:                    
                     coro_list.append(asyncio.to_thread(self.on_interact, **self.on_interact_data, **{"screen": self, "coords":  InteractEvent(x,y, action)}))
-                _LOGGER.trace("Added screen interact function to click coro list")
+                _LOGGER.verbose("Added screen interact function to click coro list")
             except (TypeError, KeyError, IndexError, OSError) as exce:
                 _LOGGER.error(f"adding on_interact function {self.on_interact} raised exception: {exce}")
             
@@ -1564,7 +1577,7 @@ class PSSMScreen:
             _LOGGER.debug("on_interact is False")
         
         if self.popupsOnTop:
-            _LOGGER.trace("Passing click to the popup on top")
+            _LOGGER.verbose("Passing click to the popup on top")
             popup = self.popupsOnTop[-1]
             if tools.coords_in_area(x, y, popup.area):
                 for p in self.popupsOnTop: # if p != popup:
@@ -1595,7 +1608,7 @@ class PSSMScreen:
 
                 if tools.coords_in_area(x, y, elt.area):
                     if hasattr(elt,"tap_action") and elt != None:
-                        _LOGGER.trace("Got element with tap_action")
+                        _LOGGER.verbose("Got element with tap_action")
                         coro_list.extend(
                             await self._dispatch_click_to_element(InteractEvent(x,y, action), elt) )
                         _LOGGER.debug("tap_action added to coro list")
@@ -1603,13 +1616,13 @@ class PSSMScreen:
 
         _LOGGER.debug(f"There are {len(coro_list)} coros in the list")
         if coro_list:
-            _LOGGER.trace("Going to await coro list")
+            _LOGGER.verbose("Going to await coro list")
             L = await asyncio.gather(*coro_list, return_exceptions=True)
             for i, res in enumerate(L):
                 if isinstance(res,Exception): 
                     _LOGGER.error(f"{coro_list[i]} returned an exception: {res} ")
                     if const.RAISE: raise res
-            _LOGGER.trace(f"Click  {x,y} coroutine gather returned with {L}")
+            _LOGGER.verbose(f"Click  {x,y} coroutine gather returned with {L}")
             
     def __stop_printing(self):
         "This is not implemnted (And should probably not be used?)"
@@ -1666,7 +1679,7 @@ class PSSMScreen:
                         msg = f"Something went wrong in {elt} tap_action {elt.tap_action}: {exce}"
                         _LOGGER.error(msg)
                 
-        _LOGGER.trace(f"Returning coro list of size {len(coro_list)}")
+        _LOGGER.verbose(f"Returning coro list of size {len(coro_list)}")
         return coro_list
     
     
@@ -1906,12 +1919,12 @@ class PSSMScreen:
         if not self.device.backlight.state or self.device.backlight.brightness != brightness:
             self.device.backlight.turn_on(brightness, transition)
         
-        _LOGGER.trace(f"Turning backlight off again in {time_on} seconds")
+        _LOGGER.verbose(f"Turning backlight off again in {time_on} seconds")
         
 
         try:
             await asyncio.sleep(time_on)  #@IgnoreException
-            _LOGGER.trace("Done sleeping, turning off backlight")
+            _LOGGER.verbose("Done sleeping, turning off backlight")
             self.device.backlight.turn_off(transition)
         except asyncio.CancelledError:
             pass
